#!/bin/sh
#
# Filename    : createAPISections.sh
# Description : Calls createAPISection.py for a set of files.
# Author(s)   : The SBML Team <sbml-team@caltech.edu>
# Created     : 2003-07-16
# Revision    : $Id: createAPISections.sh,v 1.6 2004/07/24 01:06:40 mhucka Exp $
# Source      : $Source: /cvsroot/sbml/libsbml/docs/src/createAPISections.sh,v $
#
# Copyright 2003 California Institute of Technology and
# Japan Science and Technology Corporation.
#
# This library is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation; either version 2.1 of the License, or
# any later version.
#
# This library is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY, WITHOUT EVEN THE IMPLIED WARRANTY OF
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  The software and
# documentation provided hereunder is on an "as is" basis, and the
# California Institute of Technology and Japan Science and Technology
# Corporation have no obligations to provide maintenance, support,
# updates, enhancements or modifications.  In no event shall the
# California Institute of Technology or the Japan Science and Technology
# Corporation be liable to any party for direct, indirect, special,
# incidental or consequential damages, including lost profits, arising
# out of the use of this software and its documentation, even if the
# California Institute of Technology and/or Japan Science and Technology
# Corporation have been advised of the possibility of such damage.  See
# the GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this library; if not, write to the Free Software Foundation,
# Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
#
# The original code contained here was initially developed by:
#
#     Ben Bornstein
#     
#     The SBML Team
#     Control and Dynamical Systems, MC 107-81
#     California Institute of Technology
#     Pasadena, CA, 91125, USA
#
#     http://sbml.org
#     mailto:sbml-team@caltech.edu
#
# Contributor(s):
# 2004-04-15 <mhucka@caltech.edu> Various tiny enhancements.
#

#
# Configurable variables
# 

OUTPUT_DIR=api

##
## Usage: createAPISections.sh <directory>
##
## Calls createAPISection.py for each header file in directory.
##
## The results are saved in the api/ subdirectory to basename.tex,
## where basename is the header filename without the '.h' extension.
##


#
# If no arguments are given, print usage statement above and exit.
#
if [ $# -lt 1 ]; then
  grep "^##" $0 | sed 's/##//'
  exit;
fi

HEADERS_DIR=$1
CWD=`pwd`

if [ ! -d ${OUTPUT_DIR} ]; then
  mkdir -p ${OUTPUT_DIR};
fi

cd ${HEADERS_DIR}
FILES=`ls *.h | sed 's/\.h//'`

cd ${CWD}

for f in ${FILES}; do
  echo Extracting docs for $f
  ./createAPISection.py ${HEADERS_DIR}/${f}.h > ${OUTPUT_DIR}/${f}.tex
done
