/**
 * Filename    : CompartmentGlyph.hpp
 * Description : SBML Layout CompartmentGlyph C++ Header
 * Organization: European Media Laboratories Research gGmbH
 * Created     : 2004-07-15
 *
 * Copyright 2004 European Media Laboratories Research gGmbH
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY, WITHOUT EVEN THE IMPLIED WARRANTY OF
 * MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  The software and
 * documentation provided hereunder is on an "as is" basis, and the
 * European Media Laboratories Research gGmbH have no obligations to provide maintenance, support,
 * updates, enhancements or modifications.  In no event shall the
 * European Media Laboratories Research gGmbH be liable to any party for direct, indirect, special,
 * incidental or consequential damages, including lost profits, arising
 * out of the use of this software and its documentation, even if the
 * European Media Laboratories Research gGmbH have been advised of the possibility of such damage.  See
 * the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * The original code contained here was initially developed by:
 *
 *     Ralph Gauges
 *     Bioinformatics Group
 *     European Media Laboratories Research gGmbH
 *     Schloss-Wolfsbrunnenweg 31c
 *     69118 Heidelberg
 *     Germany
 *
 *     http://www.eml-research.de/english/Research/BCB/
 *     mailto:ralph.gauges@eml-r.villa-bosch.de
 *
 * Contributor(s):
 */

#ifndef CompartmentGlyph_HPP__
#define CompartmentGlyph_HPP__

#include <string>
#include "sbml/layout/GraphicalObject.hpp"

class CompartmentGlyph:public GraphicalObject{
    protected:
        std::string compartment;
        
        friend class LayoutHandler;

    public:
        
        /**
         * Default Constructor which creates a new CompartmentGlyph.  Id and associated compartment id are unset.
         */
        LIBSBML_EXTERN
        CompartmentGlyph();
        
        /**
         * Constructor which creates a new CompartmentGlyph.  Id and associated compartment id are set to copies of the values given as arguments.
         */
        LIBSBML_EXTERN
        CompartmentGlyph(const std::string& id,const std::string& compartmentId);

        /**
         * Destructor.
         */        
        LIBSBML_EXTERN
        virtual ~CompartmentGlyph(); 

        /**
         * Returns the id of the associated compartment.
         */        
        LIBSBML_EXTERN
        const std::string& getCompartmentId() const;
        
        /**
         * Sets the id of the associated compartment.
         */ 
        LIBSBML_EXTERN
        void setCompartmentId(const std::string& id); 

        /**
         * Returns true if the id of the associated compartment is not the empty string.
         */  
        LIBSBML_EXTERN
        bool isSetCompartmentId() const;    
        
        /**
         * Calls initDefaults from GraphicalObject.
         */ 
        LIBSBML_EXTERN
        void initDefaults();
};


#endif
