/**
 * Filename    : GraphicalObject.hpp
 * Description : SBML Layout GraphicalObject C++ Header
 * Organization: European Media Laboratories Research gGmbH
 * Created     : 2004-07-15
 *
 * Copyright 2004 European Media Laboratories Research gGmbH
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY, WITHOUT EVEN THE IMPLIED WARRANTY OF
 * MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  The software and
 * documentation provided hereunder is on an "as is" basis, and the
 * European Media Laboratories Research gGmbH have no obligations to provide maintenance, support,
 * updates, enhancements or modifications.  In no event shall the
 * European Media Laboratories Research gGmbH be liable to any party for direct, indirect, special,
 * incidental or consequential damages, including lost profits, arising
 * out of the use of this software and its documentation, even if the
 * European Media Laboratories Research gGmbH have been advised of the possibility of such damage.  See
 * the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * The original code contained here was initially developed by:
 *
 *     Ralph Gauges
 *     Bioinformatics Group
 *     European Media Laboratories Research gGmbH
 *     Schloss-Wolfsbrunnenweg 31c
 *     69118 Heidelberg
 *     Germany
 *
 *     http://www.eml-research.de/english/Research/BCB/
 *     mailto:ralph.gauges@eml-r.villa-bosch.de
 *
 * Contributor(s):
 */

#ifndef GraphicalObject_HPP__
#define GraphicalObject_HPP__

#include <string>
#include "sbml/SBase.hpp"

#include "sbml/layout/BoundingBox.hpp"

class GraphicalObject:public SBase{
    protected:
        std::string id;
        BoundingBox boundingBox;

        friend class LayoutHandler;
        
    public:

        /**
         * Creates a new GraphicalObject.
         */
        LIBSBML_EXTERN
        GraphicalObject();

        /**
         * Creates a new GraphicalObject with the given id.
         */
        LIBSBML_EXTERN
        GraphicalObject(const std::string& id);

        /**
         * Creates a new GraphicalObject with the given id and 2D coordinates for the bounding box.
         */
        LIBSBML_EXTERN
        GraphicalObject(const std::string& id,double x,double y,double w,double h);

        /**
         * Creates a new GraphicalObject with the given id and 3D coordinates for the bounding box.
         */
        LIBSBML_EXTERN
        GraphicalObject(const std::string& id,double x,double y,double z,double w,double h,double d);

        /**
         * Creates a new GraphicalObject with the given id and 3D coordinates for the bounding box.
         */
        LIBSBML_EXTERN
        GraphicalObject(const std::string& id,const Point& p,const Dimensions& d);

        /**
         * Creates a new GraphicalObject with the given id and 3D coordinates for the bounding box.
         */
        LIBSBML_EXTERN
        GraphicalObject(const std::string& id,const BoundingBox& bb);

        /**
         * Destructor.
         */ 
        LIBSBML_EXTERN
        virtual ~GraphicalObject();

        /**
         * Does nothing. No defaults are defined for GraphicalObject.
         */ 
        LIBSBML_EXTERN
        void initDefaults();

        /**
         * Gets the id for the GraphicalObject.
         */
        LIBSBML_EXTERN
        const std::string& getId() const;

        /**
         * Sets the id for the GraphicalObject.
         */
        LIBSBML_EXTERN
        void setId(const std::string& id);

        /**
         * Sets the boundingbox for the GraphicalObject.
         */ 
        LIBSBML_EXTERN
        void setBoundingBox(const BoundingBox& bb);

        /**
         * Returns the bounding box for the GraphicalObject.
         */ 
        LIBSBML_EXTERN
        BoundingBox& getBoundingBox();  

        /**
         * Returns the bounding box for the GraphicalObject.
         */ 
        LIBSBML_EXTERN
        const BoundingBox& getBoundingBox() const;  

};

#endif 
