/**
 * Filename    : LineSegment.hpp
 * Description : SBML Layout LineSegment C++ Header
 * Organization: European Media Laboratories Research gGmbH
 * Created     : 2004-07-15
 *
 * Copyright 2004 European Media Laboratories Research gGmbH
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY, WITHOUT EVEN THE IMPLIED WARRANTY OF
 * MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  The software and
 * documentation provided hereunder is on an "as is" basis, and the
 * European Media Laboratories Research gGmbH have no obligations to provide maintenance, support,
 * updates, enhancements or modifications.  In no event shall the
 * European Media Laboratories Research gGmbH be liable to any party for direct, indirect, special,
 * incidental or consequential damages, including lost profits, arising
 * out of the use of this software and its documentation, even if the
 * European Media Laboratories Research gGmbH have been advised of the possibility of such damage.  See
 * the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * The original code contained here was initially developed by:
 *
 *     Ralph Gauges
 *     Bioinformatics Group
 *     European Media Laboratories Research gGmbH
 *     Schloss-Wolfsbrunnenweg 31c
 *     69118 Heidelberg
 *     Germany
 *
 *     http://www.eml-research.de/english/Research/BCB/
 *     mailto:ralph.gauges@eml-r.villa-bosch.de
 *
 * Contributor(s):
 */

#ifndef LineSegment_HPP__
#define LineSegment_HPP__

#include <string>
#include "sbml/SBase.hpp"

#include "sbml/layout/Point.hpp"

class LineSegment:public SBase{
    protected:
        std::string id;
        Point startPoint;
        Point endPoint;

    public:
        /**
         * Creates a line segment with both points set to (0.0,0.0,0.0)
         */ 
        LIBSBML_EXTERN
            LineSegment();

        /**
         * Creates a new line segment with the given 2D coordinates.
         */ 
        LIBSBML_EXTERN
            LineSegment(double x1,double y1,double x2,double y2);

        /**
         * Creates a new line segment with the given 3D coordinates.
         */ 
        LIBSBML_EXTERN
            LineSegment(double x1,double y1,double z1,double x2,double y2,double z2);

        /**
         * Creates a new line segment with the two given points.
         */ 
        LIBSBML_EXTERN
            LineSegment(const Point& start,const Point& end);

        /**
         * Destructor.
         */ 
        LIBSBML_EXTERN
            virtual ~LineSegment();

        /**
         * Sets the id to a copy of the given string.
         */     
        LIBSBML_EXTERN
            void setId(const std::string&);

        /**
         * Returns the id.
         */ 
        LIBSBML_EXTERN
            const std::string& getId() const;

        /**
         * Returns the start point of the line.
         */ 
        LIBSBML_EXTERN
            const Point& getStart() const;

        /**
         * Returns the start point of the line.
         */ 
        LIBSBML_EXTERN
            Point& getStart();

        /**
         * Initializes the start point with a copy of the given Point object.
         */
        LIBSBML_EXTERN
            void setStart(const Point& start);

        /**
         * Initializes the start point with the given coordinates.
         */
        LIBSBML_EXTERN
            void setStart(double x,double y,double z=0.0);

        /**
         * Returns the end point of the line.
         */ 
        LIBSBML_EXTERN
            const Point& getEnd() const;

        /**
         * Returns the end point of the line.
         */ 
        LIBSBML_EXTERN
            Point& getEnd();

        /**
         * Initializes the end point with a copy of the given Point object.
         */
        LIBSBML_EXTERN
            void setEnd(const Point& end);

        /**
         * Initializes the end point with the given coordinates.
         */
        LIBSBML_EXTERN
            void setEnd(double x,double y,double z=0.0);

        /**
         * Does noting since no defaults are defined for LineSegment.
         */ 
        LIBSBML_EXTERN
            void initDefaults();    
};

#endif
