/**
 * Filename    : ReactionGlyph.hpp
 * Description : SBML Layout ReactionGlyph C++ Header
 * Organization: European Media Laboratories Research gGmbH
 * Created     : 2004-07-15
 *
 * Copyright 2004 European Media Laboratories Research gGmbH
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY, WITHOUT EVEN THE IMPLIED WARRANTY OF
 * MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  The software and
 * documentation provided hereunder is on an "as is" basis, and the
 * European Media Laboratories Research gGmbH have no obligations to provide maintenance, support,
 * updates, enhancements or modifications.  In no event shall the
 * European Media Laboratories Research gGmbH be liable to any party for direct, indirect, special,
 * incidental or consequential damages, including lost profits, arising
 * out of the use of this software and its documentation, even if the
 * European Media Laboratories Research gGmbH have been advised of the possibility of such damage.  See
 * the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * The original code contained here was initially developed by:
 *
 *     Ralph Gauges
 *     Bioinformatics Group
 *     European Media Laboratories Research gGmbH
 *     Schloss-Wolfsbrunnenweg 31c
 *     69118 Heidelberg
 *     Germany
 *
 *     http://www.eml-research.de/english/Research/BCB/
 *     mailto:ralph.gauges@eml-r.villa-bosch.de
 *
 * Contributor(s):
 */

#ifndef ReactionGlyph_HPP__
#define ReactionGlyph_HPP__

#include <string>
#include "sbml/layout/GraphicalObject.hpp"
#include "sbml/ListOf.hpp"
#include "sbml/layout/SpeciesReferenceGlyph.hpp"

class ReactionGlyph:public GraphicalObject{
    protected:
        std::string reaction;
        ListOf speciesReferenceGlyphs;
        Curve* curve;
        
        friend class LayoutHandler;

    public:
        /**
         * Creates a new ReactionGlyph.
         * The list of species reference glyph is empty and the id of the associated reaction is set to the empty string.
         */ 
        LIBSBML_EXTERN 
        ReactionGlyph();
       
        /**
         * Creates a ResctionGlyph with the given id and set the id of the associated reaction to the second argument.
         */ 
        LIBSBML_EXTERN 
        ReactionGlyph(const std::string& id, const std::string& reactionId);
       
        /**
         * Destructor.
         */ 
        LIBSBML_EXTERN 
        virtual ~ReactionGlyph(); 
       
        /**
         * Returns the id of the associated reaction.
         */  
        LIBSBML_EXTERN 
        const std::string& getReactionId() const;
       
        /**
         * Sets the id of the associated reaction.
         */ 
        LIBSBML_EXTERN 
        void setReactionId(const std::string& id);

        /**
         * Returns true if the id of the associated reaction is not the empty string.
         */ 
        LIBSBML_EXTERN
        bool isSetReactionId() const;    
       
        /**
         * Returns the ListOf object that hold the species reference glyphs.
         */  
        LIBSBML_EXTERN 
        const ListOf& getListOfSpeciesReferenceGlyphs() const;

        /**
         * Returns the ListOf object that hold the species reference glyphs.
         */  
        LIBSBML_EXTERN 
        ListOf& getListOfSpeciesReferenceGlyphs();
       
        /**
         * Returns the species reference glyph with the given index.
         * If the index is invalid, NULL is returned.
         */ 
        LIBSBML_EXTERN 
        SpeciesReferenceGlyph* getSpeciesReferenceGlyph(unsigned int index) const;
       
        /**
         * Adds a new species reference glyph to the list.
         */
        LIBSBML_EXTERN 
        void addSpeciesReferenceGlyph(SpeciesReferenceGlyph& glyph);
       
        /**
         * Returns the number of species reference glyph objects.
         */ 
        LIBSBML_EXTERN 
        unsigned int getNumSpeciesReferenceGlyphs() const;
       
        /**
         * Calls initDefaults from GraphicalObject.
         */ 
        LIBSBML_EXTERN 
        void initDefaults(); 

        /**
         * Returns the curve object for the reaction glyph
         */ 
        LIBSBML_EXTERN
        Curve* getCurve() const;

        /**
         * Sets the curve object for the reaction glyph.
         */ 
        LIBSBML_EXTERN
        void setCurve(Curve* curve);
       
        /**
         * Returns true if the curve consists of one or more segments.
         */ 
        LIBSBML_EXTERN
        bool isSetCurve() const;

        /**
         * Creates a new SpeciesReferenceGlyph object, adds it to the end of the list of species
         * reference objects and returns a reference to the newly created object.
         */
        LIBSBML_EXTERN
        SpeciesReferenceGlyph&
        createSpeciesReferenceGlyph();
        
        /**
         * Creates a new LineSegment object, adds it to the end of the list of curve
         * segment objects of the curve and returns a reference to the newly created object.
         */
        LIBSBML_EXTERN
        LineSegment&
        createLineSegment();
    
        /**
         * Creates a new CubicBezier object, adds it to the end of the list of curve
         * segment objects of the curve and returns a reference to the newly created object.
         */
        LIBSBML_EXTERN
        CubicBezier&
        createCubicBezier();
 
};


#endif
