/**
 * Filename    : SpeciesReferenceGlyph.h
 * Description : SBML Layout SpeciesReferenceGlyph C Header
 * Organization: European Media Laboratories Research gGmbH
 * Created     : 2004-04-26
 *
 * Copyright 2004 European Media Laboratories Research gGmbH
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY, WITHOUT EVEN THE IMPLIED WARRANTY OF
 * MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  The software and
 * documentation provided hereunder is on an "as is" basis, and the
 * European Media Laboratories Research gGmbH have no obligations to provide maintenance, support,
 * updates, enhancements or modifications.  In no event shall the
 * European Media Laboratories Research gGmbH be liable to any party for direct, indirect, special,
 * incidental or consequential damages, including lost profits, arising
 * out of the use of this software and its documentation, even if the
 * European Media Laboratories Research gGmbH have been advised of the possibility of such damage.  See
 * the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * The original code contained here was initially developed by:
 *
 *     Ralph Gauges
 *     Bioinformatics Group
 *     European Media Laboratories Research gGmbH
 *     Schloss-Wolfsbrunnenweg 31c
 *     69118 Heidelberg
 *     Germany
 *
 *     http://www.eml-research.de/english/Research/BCB/
 *     mailto:ralph.gauges@eml-r.villa-bosch.de
 *
 * Contributor(s):
 */




#ifndef SpeciesReferenceGlyph_h
#define SpeciesReferenceGlyph_h

#include "sbml/layout/Curve.h"
#include "sbml/layout/SpeciesReferenceRole.h"

BEGIN_C_DECLS


typedef void SpeciesReferenceGlyph_t;


/**
 * Creates a new SpeciesReferenceGlyph object and returns a pointer to it.
 */
LIBSBML_EXTERN
SpeciesReferenceGlyph_t*
SpeciesReferenceGlyph_create();

/**
 * Creates a new SpeciesReferenceGlyph from a template.
 */
LIBSBML_EXTERN
SpeciesReferenceGlyph_t*
SpeciesReferenceGlyph_createFrom(const SpeciesReferenceGlyph_t* temp);

/**
 * Creates a new SpeciesReferenceGlyph object with the given id and returns a pointer to it.
 */
LIBSBML_EXTERN
SpeciesReferenceGlyph_t*
SpeciesReferenceGlyph_createWith(const char* sid,const char* speciesGlyphId,const char* speciesReferenceId,SpeciesReferenceRole_t role);


/**
 * Frees the memory for the SpeciesReferenceGlyph
 */
LIBSBML_EXTERN
void
SpeciesReferenceGlyph_free(SpeciesReferenceGlyph_t* srg);


/**
 * Sets the reference species for the species glyph.
 */
LIBSBML_EXTERN
void
SpeciesReferenceGlyph_setSpeciesReferenceId(SpeciesReferenceGlyph_t* srg,const char* c);

/**
 * Gets the reference species id for the given species glyph.
 */
LIBSBML_EXTERN
const char*
SpeciesReferenceGlyph_getSpeciesReferenceId(const SpeciesReferenceGlyph_t* srg);

/**
 * Returns 0 if the reference species reference has not been set for this glyph and 1
 * otherwise.
 */
LIBSBML_EXTERN
int
SpeciesReferenceGlyph_isSetSpeciesReferenceId(const SpeciesReferenceGlyph_t* srg);

/**
 * Sets the species glyph reference for the species glyph.
 */
LIBSBML_EXTERN
void
SpeciesReferenceGlyph_setSpeciesGlyphId(SpeciesReferenceGlyph_t* srg,const char* c);

/**
 * Gets the reference speciess id for the given species glyph.
 */
LIBSBML_EXTERN
const char*
SpeciesReferenceGlyph_getSpeciesGlyphId(const SpeciesReferenceGlyph_t* srg);

/**
 * Returns 0 if the reference species reference has not been set for this glyph and 1
 * otherwise.
 */
LIBSBML_EXTERN
int
SpeciesReferenceGlyph_isSetSpeciesGlyphId(const SpeciesReferenceGlyph_t* srg);


/**
 * Sets the curve for the species reference glyph.
 */
LIBSBML_EXTERN
void
SpeciesReferenceGlyph_setCurve(SpeciesReferenceGlyph_t* srg,Curve_t* c);

/**
 * Gets the Curve for the given species reference glyph.
 */
LIBSBML_EXTERN
Curve_t*
SpeciesReferenceGlyph_getCurve(const SpeciesReferenceGlyph_t* srg);

/**
 * Returns true if the Curve has one or more LineSegment.
 */
LIBSBML_EXTERN
int
SpeciesReferenceGlyph_isSetCurve(SpeciesReferenceGlyph_t* srg);

/**
 * Sets the role of the species reference glyph based on the string.
 * The string can be one of UNDEFINED, SUBSTRATE, PRODUCT, SIDESUBSTRATE, SIDEPRODUCT, MODIFIER, INHIBITOR or ACTIVATOR.
 * If it is none of those, the role is set to SPECIES_ROLE_UNDEFINED.
 */
LIBSBML_EXTERN
void
SpeciesReferenceGlyph_setRole(SpeciesReferenceGlyph_t* srg,const char* r);

/**
 * Returns the role of the species reference.
 */ 
LIBSBML_EXTERN
SpeciesReferenceRole_t
SpeciesReferenceGlyph_getRole(const SpeciesReferenceGlyph_t* srg);

/**
 * Returns true if the role is not SPECIES_ROLE_UNDEFINED.
 */ 
LIBSBML_EXTERN
int
SpeciesReferenceGlyph_isSetRole(const SpeciesReferenceGlyph_t* srg);

/**
 * Calls initDefaults on GraphicalObject and sets role to SPECIES_ROLE_UNDEFINED.
 */ 
LIBSBML_EXTERN
void
SpeciesReferenceGlyph_initDefaults(SpeciesReferenceGlyph_t* srg);

/**
 * Creates a new LineSegment object, adds it to the end of the list of curve
 * segment objects of the curve and returns a reference to the newly created object.
 */
LIBSBML_EXTERN
LineSegment_t*
SpeciesReferenceGlyph_createLineSegment(SpeciesReferenceGlyph_t* srg);
  
/**
 * Creates a new CubicBezier object, adds it to the end of the list of curve
 * segment objects of the curve and returns a reference to the newly created object.
 */
LIBSBML_EXTERN
CubicBezier_t*
SpeciesReferenceGlyph_createCubicBezier(SpeciesReferenceGlyph_t* srg);


END_C_DECLS





#endif
