/**
 * Filename    : TextGlyph.h
 * Description : SBML Layout TextGlyph C Header
 * Organization: European Media Laboratories Research gGmbH
 * Created     : 2004-04-26
 *
 * Copyright 2004 European Media Laboratories Research gGmbH
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY, WITHOUT EVEN THE IMPLIED WARRANTY OF
 * MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  The software and
 * documentation provided hereunder is on an "as is" basis, and the
 * European Media Laboratories Research gGmbH have no obligations to provide maintenance, support,
 * updates, enhancements or modifications.  In no event shall the
 * European Media Laboratories Research gGmbH be liable to any party for direct, indirect, special,
 * incidental or consequential damages, including lost profits, arising
 * out of the use of this software and its documentation, even if the
 * European Media Laboratories Research gGmbH have been advised of the possibility of such damage.  See
 * the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * The original code contained here was initially developed by:
 *
 *     Ralph Gauges
 *     Bioinformatics Group
 *     European Media Laboratories Research gGmbH
 *     Schloss-Wolfsbrunnenweg 31c
 *     69118 Heidelberg
 *     Germany
 *
 *     http://www.eml-research.de/english/Research/BCB/
 *     mailto:ralph.gauges@eml-r.villa-bosch.de
 *
 * Contributor(s):
 */

#ifndef TextGlyph_h
#define TextGlyph_h


BEGIN_C_DECLS

typedef void TextGlyph_t;


/**
 * Creates a new TextGlyph and returns the pointer to it.
 */
LIBSBML_EXTERN
TextGlyph_t*
TextGlyph_create();

/**
 * Creates a new TextGlyph from a template.
 */
LIBSBML_EXTERN
TextGlyph_t*
TextGlyph_createFrom(const TextGlyph_t* temp);

/**
 * Creates a new TextGlyph with the given id
 */
LIBSBML_EXTERN
TextGlyph_t*
TextGlyph_createWith(const char* sid);

/**
 * Creates a new TextGlyph referencing the give text.
 */
LIBSBML_EXTERN
TextGlyph_t*
TextGlyph_createWithText(const char* id,const char* text);

/**
 * Frees the memory taken by the given text glyph.
 */
LIBSBML_EXTERN
void
TextGlyph_free(TextGlyph_t* cg);

/**
 * Sets the text for the text glyph.
 */
LIBSBML_EXTERN
void
TextGlyph_setText(TextGlyph_t* cg,const char* text);

/**
 * Sets the id of the origin of the text for the text glyph.
 * This can be the id of any valid sbml model object. The name of the object is
 * then taken as the text for the TextGlyph.
 */
LIBSBML_EXTERN
void
TextGlyph_setOriginOfTextId(TextGlyph_t* cg,const char* sid);

/**
 * Sets the assoziated GraphicalObject id for the text glyph.
 * A TextGlyph which is assoziated with a GraphicalObject can be considered as
 * a label to that object and they might for example be moved together in an
 * editor.
 */
LIBSBML_EXTERN
void
TextGlyph_setGraphicalObjectId(TextGlyph_t* cg,const char* sid);


/**
 * Returns the text associated with this text glyph.
 */
LIBSBML_EXTERN
const char*
TextGlyph_getText(const TextGlyph_t* cg);

/**
 * Returns the id of the origin of the text associated with this text glyph.
 */
LIBSBML_EXTERN
const char*
TextGlyph_getOriginOfTextId(const TextGlyph_t* cg);

/**
 * Returns the id of the graphical object associated with this text glyph.
 */
LIBSBML_EXTERN
const char*
TextGlyph_getGraphicalObjectId(const TextGlyph_t* cg);


/**
 * Returns true is the text attribute is not the empty string.
 */
LIBSBML_EXTERN
int
TextGlyph_isSetText(const TextGlyph_t* tg);


/**
 * Returns true is the originOfText attribute is not the empty string.
 */
LIBSBML_EXTERN
int
TextGlyph_isSetOriginOfTextId(const TextGlyph_t* tg);


/**
 * Returns true is the id of the associated graphical object is not the empty string.
 */
LIBSBML_EXTERN
int
TextGlyph_isSetGraphicalObjectId(const TextGlyph_t* tg);

/**
 * Calls initDefaults from GraphicalObject.
 */ 
LIBSBML_EXTERN
void
TextGlyph_initDefaults(TextGlyph_t* tg);

END_C_DECLS



#endif
