/**
 * Filename    : TextGlyph.hpp
 * Description : SBML Layout TextGlyph C++ Header
 * Organization: European Media Laboratories Research gGmbH
 * Created     : 2004-07-15
 *
 * Copyright 2004 European Media Laboratories Research gGmbH
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY, WITHOUT EVEN THE IMPLIED WARRANTY OF
 * MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  The software and
 * documentation provided hereunder is on an "as is" basis, and the
 * European Media Laboratories Research gGmbH have no obligations to provide maintenance, support,
 * updates, enhancements or modifications.  In no event shall the
 * European Media Laboratories Research gGmbH be liable to any party for direct, indirect, special,
 * incidental or consequential damages, including lost profits, arising
 * out of the use of this software and its documentation, even if the
 * European Media Laboratories Research gGmbH have been advised of the possibility of such damage.  See
 * the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * The original code contained here was initially developed by:
 *
 *     Ralph Gauges
 *     Bioinformatics Group
 *     European Media Laboratories Research gGmbH
 *     Schloss-Wolfsbrunnenweg 31c
 *     69118 Heidelberg
 *     Germany
 *
 *     http://www.eml-research.de/english/Research/BCB/
 *     mailto:ralph.gauges@eml-r.villa-bosch.de
 *
 * Contributor(s):
 */

#ifndef TextGlyph_HPP__
#define TextGlyph_HPP__

#include <string>
#include "sbml/layout/GraphicalObject.hpp"

class TextGlyph:public GraphicalObject{
    protected:
        std::string text;
        std::string graphicalObject;
        std::string originOfText;

    public:
        /**
         * Creates a new TextGlyph the ids of the associated GraphicalObject and the originOfText are set to the empty string. The actual text is set to the empty string as well.
        */  
        LIBSBML_EXTERN
        TextGlyph();
        
        /**
         * Creates a new TextGlpyh. The id is given as the first argument, the text to be displayed as the second.
         * All other attirbutes are set to the empty string.
         */ 
        LIBSBML_EXTERN
        TextGlyph(const std::string& id,const std::string& text);
        
        /**
         * Destructor.
         */ 
        LIBSBML_EXTERN
        virtual ~TextGlyph(); 
        
        /**
         * Returns the text to be displayed by the text glyph.
         */ 
        LIBSBML_EXTERN
        const std::string& getText() const;
        
        /**
         * Sets the text to be displayed by the text glyph.
         */ 
        LIBSBML_EXTERN
        void setText(const std::string& text); 
        
        /**
         * Returns the id of the associated graphical object.
         */ 
        LIBSBML_EXTERN
        const std::string& getGraphicalObjectId() const;
        
        /**
         * Sets the id of the associated graphical object.
         */ 
        LIBSBML_EXTERN
        void setGraphicalObjectId(const std::string& id); 
        
        /**
         * Returns the id of the origin of text.
         */ 
        LIBSBML_EXTERN
        const std::string& getOriginOfTextId() const;
        
        /**
         * Sets the id of the origin of text.
         */ 
        LIBSBML_EXTERN
        void setOriginOfTextId(const std::string& orig); 
        
        /**
         * Returns true if the text is not the empty string.
         */ 
        LIBSBML_EXTERN
        bool isSetText() const;
        
        /**
         * Returns true if the id of the origin of text is not the empty string.
         */ 
        LIBSBML_EXTERN
        bool isSetOriginOfTextId() const;
        
        /**
         * Returns true if the id of the associated graphical object is not the empty string.
         */ 
        LIBSBML_EXTERN
        bool isSetGraphicalObjectId() const;
        
        /**
         * Calls initDefaults from GraphicalObject.
         */ 
        LIBSBML_EXTERN
        void initDefaults();
};


#endif
