/**
 * Filename    : TestMathMLWriter.c
 * Description : MathMLWriter unit tests
 * Author(s)   : SBML Development Group <sbml-team@caltech.edu>
 * Organization: JST ERATO Kitano Symbiotic Systems Project
 * Created     : 2003-07-30
 * Revision    : $Id: TestMathMLWriter.c,v 1.4 2004/07/24 01:06:03 mhucka Exp $
 * Source      : $Source: /cvsroot/sbml/libsbml/src/TestMathMLWriter.c,v $
 *
 * Copyright 2003 California Institute of Technology and
 * Japan Science and Technology Corporation.
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY, WITHOUT EVEN THE IMPLIED WARRANTY OF
 * MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  The software and
 * documentation provided hereunder is on an "as is" basis, and the
 * California Institute of Technology and Japan Science and Technology
 * Corporation have no obligations to provide maintenance, support,
 * updates, enhancements or modifications.  In no event shall the
 * California Institute of Technology or the Japan Science and Technology
 * Corporation be liable to any party for direct, indirect, special,
 * incidental or consequential damages, including lost profits, arising
 * out of the use of this software and its documentation, even if the
 * California Institute of Technology and/or Japan Science and Technology
 * Corporation have been advised of the possibility of such damage.  See
 * the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * The original code contained here was initially developed by:
 *
 *     Ben Bornstein
 *     The Systems Biology Markup Language Development Group
 *     ERATO Kitano Symbiotic Systems Project
 *     Control and Dynamical Systems, MC 107-81
 *     California Institute of Technology
 *     Pasadena, CA, 91125, USA
 *
 *     http://www.cds.caltech.edu/erato
 *     mailto:sbml-team@caltech.edu
 *
 * Contributor(s):
 */


#include <check.h>

#include "sbml/common.h"

#include "sbml/FormulaParser.h"

#include "sbml/MathMLReader.h"
#include "sbml/MathMLWriter.h"


extern char *TestDataDirectory;


START_TEST (test_MathMLWriter_writeMathMLToString)
{
  char             *s;
  MathMLDocument_t *d = MathMLDocument_create();

  const char *expected =
  (
    "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
    "<math xmlns=\"http://www.w3.org/1998/Math/MathML\">\n"
    "  <apply>\n"
    "    <plus/>\n"
    "    <ci> a </ci>\n"
    "    <ci> b </ci>\n"
    "  </apply>\n"
    "</math>\n"
  );

  MathMLDocument_setMath(d, SBML_parseFormula("a + b"));
  s = writeMathMLToString(d);

  fail_unless( !strcmp(s, expected), NULL );

  MathMLDocument_free(d);
  safe_free(s);
}
END_TEST


Suite *
create_suite_MathMLWriter (void) 
{ 
  Suite *suite = suite_create("MathMLWriter");
  TCase *tcase = tcase_create("MathMLWriter");
 

  tcase_add_test(tcase, test_MathMLWriter_writeMathMLToString);

  suite_add_tcase(suite, tcase);

  return suite;
}
